<?php
/**
 * VW Magazine Theme Customizer
 *
 * @package VW Magazine
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_magazine_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_magazine_custom_controls' );

function vw_magazine_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

    //Selective Refresh
    $wp_customize->selective_refresh->add_partial( 'blogname', array( 
        'selector' => '.logo .site-title a', 
        'render_callback' => 'vw_magazinee_customize_partial_blogname', 
    )); 

    $wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
        'selector' => 'p.site-description', 
        'render_callback' => 'vw_magazinee_customize_partial_blogdescription', 
    ));

	$VWMagazineParentPanel = new VW_Magazine_WP_Customize_Panel( $wp_customize, 'vw_magazine_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => 'VW Settings',
		'priority' => 10,
	));

	$wp_customize->add_section( 'vw_magazine_left_right', array(
    	'title'      => __( 'General Settings', 'vw-magazine' ),
		'panel' => 'vw_magazine_panel_id'
	) );

	$wp_customize->add_setting('vw_magazine_width_option',array(
        'default' => __('Full Width','vw-magazine'),
        'sanitize_callback' => 'vw_magazine_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Magazine_Image_Radio_Control($wp_customize, 'vw_magazine_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-magazine'),
        'description' => __('Here you can change the width layout of Website.','vw-magazine'),
        'section' => 'vw_magazine_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_magazine_theme_options',array(
        'default' => __('Right Sidebar','vw-magazine'),
        'sanitize_callback' => 'vw_magazine_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_magazine_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-magazine'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-magazine'),
        'section' => 'vw_magazine_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-magazine'),
            'Right Sidebar' => __('Right Sidebar','vw-magazine'),
            'One Column' => __('One Column','vw-magazine'),
            'Three Columns' => __('Three Columns','vw-magazine'),
            'Four Columns' => __('Four Columns','vw-magazine'),
            'Grid Layout' => __('Grid Layout','vw-magazine')
        ),
	));

	$wp_customize->add_setting('vw_magazine_page_layout',array(
        'default' => __('One Column','vw-magazine'),
        'sanitize_callback' => 'vw_magazine_sanitize_choices'
	));
	$wp_customize->add_control('vw_magazine_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-magazine'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-magazine'),
        'section' => 'vw_magazine_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-magazine'),
            'Right Sidebar' => __('Right Sidebar','vw-magazine'),
            'One Column' => __('One Column','vw-magazine')
        ),
	) );

	//Pre-Loader
	$wp_customize->add_setting( 'vw_magazine_loader_enable',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','vw-magazine' ),
        'section' => 'vw_magazine_left_right'
    )));

	$wp_customize->add_setting('vw_magazine_loader_icon',array(
        'default' => __('Two Way','vw-magazine'),
        'sanitize_callback' => 'vw_magazine_sanitize_choices'
	));
	$wp_customize->add_control('vw_magazine_loader_icon',array(
        'type' => 'select',
        'label' => __('Pre-Loader Type','vw-magazine'),
        'section' => 'vw_magazine_left_right',
        'choices' => array(
            'Two Way' => __('Two Way','vw-magazine'),
            'Dots' => __('Dots','vw-magazine'),
            'Rotate' => __('Rotate','vw-magazine')
        ),
	) );
    
	//Topbar section
	$wp_customize->add_section('vw_magazine_topbar',array(
		'title'	=> __('Topbar Section','vw-magazine'),
		'description'	=> __('Add Topbar Content here','vw-magazine'),
		'priority'	=> null,
		'panel' => 'vw_magazine_panel_id',
	));

	$wp_customize->add_setting( 'vw_magazine_topbar_hide_show',
       array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_topbar_hide_show',
       array(
      'label' => esc_html__( 'Show / Hide Topbar','vw-magazine' ),
      'section' => 'vw_magazine_topbar'
    )));

    $wp_customize->add_setting('vw_magazine_topbar_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_topbar_padding_top_bottom',array(
		'label'	=> __('Topbar Padding Top Bottom','vw-magazine'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_topbar',
		'type'=> 'text'
	));

	//Selective Refresh
    $wp_customize->selective_refresh->add_partial('vw_magazine_contact', array( 
        'selector' => '#top-bar .contact-top span', 
        'render_callback' => 'vw_magazine_customize_partial_vw_magazine_contact', 
    ));

    $wp_customize->add_setting('vw_magazine_phone_icon',array(
		'default'	=> 'fa fa-phone',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Magazine_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_magazine_phone_icon',array(
		'label'	=> __('Add Contact Icon','vw-magazine'),
		'transport' => 'refresh',
		'section'	=> 'vw_magazine_topbar',
		'setting'	=> 'vw_magazine_phone_icon',
		'type'		=> 'icon'
	)));
	
	$wp_customize->add_setting('vw_magazine_contact',array(
		'default'	=> '',
		'sanitize_callback'	=> 'vw_magazine_sanitize_phone_number'
	));	
	$wp_customize->add_control('vw_magazine_contact',array(
		'label'	=> __('Add Contact Details','vw-magazine'),
		'section'	=> 'vw_magazine_topbar',
		'setting'	=> 'vw_magazine_contact',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_email_icon',array(
		'default'	=> 'fa fa-envelope',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Magazine_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_magazine_email_icon',array(
		'label'	=> __('Add Email Icon','vw-magazine'),
		'transport' => 'refresh',
		'section'	=> 'vw_magazine_topbar',
		'setting'	=> 'vw_magazine_email_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_magazine_email',array(
		'default'	=> '',
		'sanitize_callback'	=> 'vw_magazine_sanitize_email'
	));	
	$wp_customize->add_control('vw_magazine_email',array(
		'label'	=> __('Add Email Address','vw-magazine'),
		'section'	=> 'vw_magazine_topbar',
		'setting'	=> 'vw_magazine_email',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_header_top_headline',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_magazine_header_top_headline',array(
		'label'	=> __('Add Top Title','vw-magazine'),
		'section'	=> 'vw_magazine_topbar',
		'setting'	=> 'vw_magazine_header_top_headline',
		'type'		=> 'text'
	));

	//Header Section
	$wp_customize->add_section('vw_magazine_top_header',array(
		'title'	=> __('Header Section','vw-magazine'),
		'description'	=> __('Add Header content below.','vw-magazine'),
		'panel' => 'vw_magazine_panel_id',
	));

	$wp_customize->add_setting( 'vw_magazine_search_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_search_hide_show',array(
		'label' => esc_html__( 'Show / Hide Search','vw-magazine' ),
		'section' => 'vw_magazine_top_header'
    )));

    $wp_customize->add_setting('vw_magazine_search_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_search_font_size',array(
		'label'	=> __('Search Font Size','vw-magazine'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_top_header',
		'type'=> 'text'
	));

	//Sticky Header
	$wp_customize->add_setting( 'vw_magazine_sticky_header',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_sticky_header',array(
        'label' => esc_html__( 'Sticky Header','vw-magazine' ),
        'section' => 'vw_magazine_top_header'
    )));

    $wp_customize->add_setting('vw_magazine_sticky_header_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_sticky_header_padding',array(
		'label'	=> __('Sticky Header Padding','vw-magazine'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_top_header',
		'type'=> 'text'
	));

    //Selective Refresh
    $wp_customize->selective_refresh->add_partial('vw_magazine_header_weather_text',array(
        'selector'        => '.address.media',
        'render_callback' => 'vw_magazine_customize_partial_vw_magazine_header_weather_text',
    ));

    $wp_customize->add_setting('vw_magazine_header_weather_icon',array(
		'default'	=> 'fab fa-mixcloud',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Magazine_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_magazine_header_weather_icon',array(
		'label'	=> __('Add Weather Icon','vw-magazine'),
		'transport' => 'refresh',
		'section'	=> 'vw_magazine_top_header',
		'setting'	=> 'vw_magazine_header_weather_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_magazine_header_weather_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_magazine_header_weather_text',array(
		'label'	=> __('Add City Name','vw-magazine'),
		'section'	=> 'vw_magazine_top_header',
		'setting'	=> 'vw_magazine_header_weather_text',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_header_percent',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_magazine_header_percent',array(
		'label'	=> __('Add Weather Percnt','vw-magazine'),
		'section'	=> 'vw_magazine_top_header',
		'setting'	=> 'vw_magazine_header_percent',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_timing_icon',array(
		'default'	=> 'far fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Magazine_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_magazine_timing_icon',array(
		'label'	=> __('Add Timing Icon','vw-magazine'),
		'transport' => 'refresh',
		'section'	=> 'vw_magazine_top_header',
		'setting'	=> 'vw_magazine_timing_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_magazine_header_date',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_magazine_header_date',array(
		'label'	=> __('Add Day, Date','vw-magazine'),
		'section'	=> 'vw_magazine_top_header',
		'setting'	=> 'vw_magazine_header_date',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_header_timing',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_magazine_header_timing',array(
		'label'	=> __('Add Time','vw-magazine'),
		'section'	=> 'vw_magazine_top_header',
		'setting'	=> 'vw_magazine_header_timing',
		'type'		=> 'text'
	));

	$args = array('numberposts' => -1);
	$post_list = get_posts($args);
	$i = 0;
	$posts[]='Select';	
	foreach($post_list as $post){
		$posts[$post->post_title] = $post->post_title;
	}

	$wp_customize->add_setting('vw_magazine_top_banner_post',array(
		'sanitize_callback' => 'vw_magazine_sanitize_choices',
	));
	$wp_customize->add_control('vw_magazine_top_banner_post',array(
		'type'    => 'select',
		'choices' => $posts,
		'label' => __('Select post','vw-magazine'),
		'section' => 'vw_magazine_top_header',
	));

	$wp_customize->add_setting('vw_magazine_top_banner_button',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_top_banner_button',array(
		'label'	=> __('Button text','vw-magazine'),
		'section'	=> 'vw_magazine_top_header',
		'setting'	=> 'vw_magazine_top_banner_button',
		'type'		=> 'text'
	));

	//Post Carousel
	$wp_customize->add_section('vw_magazine_post_carousel',array(
		'title'	=> __('Post Carousel','vw-magazine'),
		'description'	=> __('Select the post category and show your post','vw-magazine'),
		'priority'	=> null,
		'panel' => 'vw_magazine_panel_id',
	));

	//Selective Refresh
    $wp_customize->selective_refresh->add_partial( 'vw_magazine_post_carousel_category', array( 
        'selector' => '.posts_box h1 a', 
        'render_callback' => 'vw_magazine_customize_partial_vw_magazine_post_carousel_category',
    ));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cats[]= 'select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cats[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_magazine_post_carousel_category',array(
		'sanitize_callback' => 'vw_magazine_sanitize_choices',
	));
	$wp_customize->add_control('vw_magazine_post_carousel_category',array(
		'type'    => 'select',
		'choices' => $cats,
		'label' => __('Select category from here','vw-magazine'),
		'section' => 'vw_magazine_post_carousel',
	));

	//Post Section Two
	$wp_customize->add_section('vw_magazine_latest_post_section',array(
		'title'	=> __('Latest Post','vw-magazine'),
		'description'	=> __('Select the post category and show your post','vw-magazine'),
		'priority'	=> null,
		'panel' => 'vw_magazine_panel_id',
	));

	//Selective Refresh
    $wp_customize->selective_refresh->add_partial( 'vw_magazine_latest_post_title', array( 
        'selector' => '.latest_posts_box h3 a', 
        'render_callback' => 'vw_magazine_customize_partial_vw_magazine_latest_post_title',
    ));

	$wp_customize->add_setting('vw_magazine_latest_post_title',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field',
	));
	$wp_customize->add_control('vw_magazine_latest_post_title',array(
		'label'	=> __('Section Title','vw-magazine'),
		'section'	=> 'vw_magazine_latest_post_section',
		'type'	=> 'text'
	));

	$categories = get_categories();
	$cats1 = array();
	$i = 0;
	$cats1[]= 'select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cats1[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_magazine_latest_post_category',array(
		'sanitize_callback' => 'vw_magazine_sanitize_choices',
	));
	$wp_customize->add_control('vw_magazine_latest_post_category',array(
		'type'    => 'select',
		'choices' => $cats1,
		'label' => __('Select category from here','vw-magazine'),
		'section' => 'vw_magazine_latest_post_section',
	));

	//Blog Post
	$wp_customize->add_panel( $VWMagazineParentPanel );

	$BlogPostParentPanel = new VW_Magazine_WP_Customize_Panel( $wp_customize, 'blog_post_parent_panel', array(
		'title' => __( 'Blog Post Settings', 'vw-magazine' ),
		'panel' => 'vw_magazine_panel_id',
	));

	$wp_customize->add_panel( $BlogPostParentPanel );

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'vw_magazine_post_settings', array(
		'title' => __( 'Post Settings', 'vw-magazine' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
    $wp_customize->selective_refresh->add_partial('vw_magazine_toggle_postdate', array( 
        'selector' => '.post-main-box h2 a', 
        'render_callback' => 'vw_magazine_customize_partial_vw_magazine_toggle_postdate', 
    ));

	$wp_customize->add_setting( 'vw_magazine_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-magazine' ),
        'section' => 'vw_magazine_post_settings'
    )));

    $wp_customize->add_setting( 'vw_magazine_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_toggle_author',array(
		'label' => esc_html__( 'Author','vw-magazine' ),
		'section' => 'vw_magazine_post_settings'
    )));

    $wp_customize->add_setting( 'vw_magazine_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-magazine' ),
		'section' => 'vw_magazine_post_settings'
    )));

    $wp_customize->add_setting( 'vw_magazine_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_magazine_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_toggle_tags', array(
		'label' => esc_html__( 'Tags','vw-magazine' ),
		'section' => 'vw_magazine_post_settings'
    )));

    $wp_customize->add_setting( 'vw_magazine_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_magazine_sanitize_number_range'
	));
	$wp_customize->add_control( 'vw_magazine_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt Length','vw-magazine' ),
		'section'     => 'vw_magazine_post_settings',
		'type'        => 'range',
		'settings'    => 'vw_magazine_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	));

	//Blog layout
    $wp_customize->add_setting('vw_magazine_blog_layout_option',array(
        'default' => __('Default','vw-magazine'),
        'sanitize_callback' => 'vw_magazine_sanitize_choices'
    ));
    $wp_customize->add_control(new VW_Magazine_Image_Radio_Control($wp_customize, 'vw_magazine_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Layouts','vw-magazine'),
        'section' => 'vw_magazine_post_settings',
        'choices' => array(
            'Default' => get_template_directory_uri().'/images/blog-layout1.png',
            'Center' => get_template_directory_uri().'/images/blog-layout2.png',
            'Left' => get_template_directory_uri().'/images/blog-layout3.png',
    ))));

    $wp_customize->add_setting('vw_magazine_excerpt_settings',array(
        'default' => __('Excerpt','vw-magazine'),
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_magazine_sanitize_choices'
    ));
    $wp_customize->add_control('vw_magazine_excerpt_settings',array(
        'type' => 'select',
        'label' => __('Post Content','vw-magazine'),
        'section' => 'vw_magazine_post_settings',
        'choices' => array(
            'Content' => __('Content','vw-magazine'),
            'Excerpt' => __('Excerpt','vw-magazine'),
            'No Content' => __('No Content','vw-magazine')
        ),
    ) );

    $wp_customize->add_setting('vw_magazine_excerpt_suffix',array(
        'default'=> '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('vw_magazine_excerpt_suffix',array(
        'label' => __('Add Excerpt Suffix','vw-magazine'),
        'input_attrs' => array(
            'placeholder' => __( '[...]', 'vw-magazine' ),
        ),
        'section'=> 'vw_magazine_post_settings',
        'type'=> 'text'
    ));

    $wp_customize->add_setting( 'vw_magazine_blog_pagination_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_blog_pagination_hide_show',array(
      'label' => esc_html__( 'Show / Hide Blog Pagination','vw-magazine' ),
      'section' => 'vw_magazine_post_settings'
    )));

	$wp_customize->add_setting( 'vw_magazine_blog_pagination_type', array(
        'default'			=> 'blog-page-numbers',
        'sanitize_callback'	=> 'vw_magazine_sanitize_choices'
    ));
    $wp_customize->add_control( 'vw_magazine_blog_pagination_type', array(
        'section' => 'vw_magazine_post_settings',
        'type' => 'select',
        'label' => __( 'Blog Pagination', 'vw-magazine' ),
        'choices'		=> array(
            'blog-page-numbers'  => __( 'Numeric', 'vw-magazine' ),
            'next-prev' => __( 'Older Posts/Newer Posts', 'vw-magazine' ),
    )));

    // Button Settings
	$wp_customize->add_section( 'vw_magazine_button_settings', array(
		'title' => __( 'Button Settings', 'vw-magazine' ),
		'panel' => 'blog_post_parent_panel',
	));

	$wp_customize->add_setting('vw_magazine_button_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_button_padding_top_bottom',array(
		'label'	=> __('Padding Top Bottom','vw-magazine'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_button_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_button_padding_left_right',array(
		'label'	=> __('Padding Left Right','vw-magazine'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_magazine_button_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_magazine_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_magazine_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','vw-magazine' ),
		'section'     => 'vw_magazine_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
    $wp_customize->selective_refresh->add_partial('vw_magazine_button_text', array( 
        'selector' => '.post-main-box .content-bttn a', 
        'render_callback' => 'vw_magazine_customize_partial_vw_magazine_button_text', 
    ));

    $wp_customize->add_setting('vw_magazine_button_text',array(
		'default'=> 'Read More',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_button_text',array(
		'label'	=> __('Add Button Text','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( 'Read More', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_button_settings',
		'type'=> 'text'
	));

	// Related Post Settings
	$wp_customize->add_section( 'vw_magazine_related_posts_settings', array(
		'title' => __( 'Related Posts Settings', 'vw-magazine' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
    $wp_customize->selective_refresh->add_partial('vw_magazine_related_post_title', array( 
        'selector' => '.related-post h3', 
        'render_callback' => 'vw_magazine_customize_partial_vw_magazine_related_post_title', 
    ));

    $wp_customize->add_setting( 'vw_magazine_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_related_post',array(
		'label' => esc_html__( 'Related Post','vw-magazine' ),
		'section' => 'vw_magazine_related_posts_settings'
    )));

    $wp_customize->add_setting('vw_magazine_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_related_post_title',array(
		'label'	=> __('Add Related Post Title','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( 'Related Post', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('vw_magazine_related_posts_count',array(
		'default'=> '3',
		'sanitize_callback'	=> 'vw_magazine_sanitize_float'
	));
	$wp_customize->add_control('vw_magazine_related_posts_count',array(
		'label'	=> __('Add Related Post Count','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '3', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_related_posts_settings',
		'type'=> 'number'
	));

	// Single Posts Settings
	$wp_customize->add_section( 'vw_magazine_single_blog_settings', array(
		'title' => __( 'Single Post Settings', 'vw-magazine' ),
		'panel' => 'blog_post_parent_panel',
	));

	$wp_customize->add_setting( 'vw_magazine_single_blog_post_navigation_show_hide',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_magazine_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_single_blog_post_navigation_show_hide', array(
		'label' => esc_html__( 'Post Navigation','vw-magazine' ),
		'section' => 'vw_magazine_single_blog_settings'
    )));

	//navigation text
	$wp_customize->add_setting('vw_magazine_single_blog_prev_navigation_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_single_blog_prev_navigation_text',array(
		'label'	=> __('Post Navigation Text','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( 'PREVIOUS', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_single_blog_next_navigation_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_single_blog_next_navigation_text',array(
		'label'	=> __('Post Navigation Text','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( 'NEXT', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_single_blog_settings',
		'type'=> 'text'
	));

    //404 Page Setting
	$wp_customize->add_section('vw_magazine_404_page',array(
		'title'	=> __('404 Page Settings','vw-magazine'),
		'panel' => 'vw_magazine_panel_id',
	));	

	$wp_customize->add_setting('vw_magazine_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_magazine_404_page_title',array(
		'label'	=> __('Add Title','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '404 Not Found', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_magazine_404_page_content',array(
		'label'	=> __('Add Text','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_404_page_button_text',array(
		'label'	=> __('Add Button Text','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( 'Return to the home page', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_404_page',
		'type'=> 'text'
	));

	//Social Icon Setting
	$wp_customize->add_section('vw_magazine_social_icon_settings',array(
		'title'	=> __('Social Icons Settings','vw-magazine'),
		'panel' => 'vw_magazine_panel_id',
	));	

	$wp_customize->add_setting('vw_magazine_social_icon_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_social_icon_font_size',array(
		'label'	=> __('Icon Font Size','vw-magazine'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_social_icon_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_social_icon_padding',array(
		'label'	=> __('Icon Padding','vw-magazine'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_social_icon_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_social_icon_width',array(
		'label'	=> __('Icon Width','vw-magazine'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_social_icon_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_social_icon_height',array(
		'label'	=> __('Icon Height','vw-magazine'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_magazine_social_icon_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_magazine_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_magazine_social_icon_border_radius', array(
		'label'       => esc_html__( 'Icon Border Radius','vw-magazine' ),
		'section'     => 'vw_magazine_social_icon_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Responsive Media Settings
	$wp_customize->add_section('vw_magazine_responsive_media',array(
		'title'	=> __('Responsive Media','vw-magazine'),
		'panel' => 'vw_magazine_panel_id',
	));

	$wp_customize->add_setting( 'vw_magazine_resp_topbar_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_resp_topbar_hide_show',array(
      'label' => esc_html__( 'Show / Hide Topbar','vw-magazine' ),
      'section' => 'vw_magazine_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_magazine_stickyheader_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_stickyheader_hide_show',array(
      'label' => esc_html__( 'Sticky Header','vw-magazine' ),
      'section' => 'vw_magazine_responsive_media'
    )));

	$wp_customize->add_setting( 'vw_magazine_metabox_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_metabox_hide_show',array(
      'label' => esc_html__( 'Show / Hide Metabox','vw-magazine' ),
      'section' => 'vw_magazine_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_magazine_sidebar_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_sidebar_hide_show',array(
      'label' => esc_html__( 'Show / Hide Sidebar','vw-magazine' ),
      'section' => 'vw_magazine_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_magazine_resp_scroll_top_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_resp_scroll_top_hide_show',array(
      'label' => esc_html__( 'Show / Hide Scroll To Top','vw-magazine' ),
      'section' => 'vw_magazine_responsive_media'
    )));

     $wp_customize->add_setting('vw_magazine_res_open_menu_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Magazine_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_magazine_res_open_menu_icon',array(
		'label'	=> __('Add Open Menu Icon','vw-magazine'),
		'transport' => 'refresh',
		'section'	=> 'vw_magazine_responsive_media',
		'setting'	=> 'vw_magazine_res_open_menu_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_magazine_res_close_menu_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Magazine_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_magazine_res_close_menu_icon',array(
		'label'	=> __('Add Close Menu Icon','vw-magazine'),
		'transport' => 'refresh',
		'section'	=> 'vw_magazine_responsive_media',
		'setting'	=> 'vw_magazine_res_close_menu_icon',
		'type'		=> 'icon'
	)));

	//Content Creation
	$wp_customize->add_section( 'vw_magazine_content_section' , array(
    	'title' => __( 'Customize Home Page Settings', 'vw-magazine' ),
		'priority' => null,
		'panel' => 'vw_magazine_panel_id'
	));

	$wp_customize->add_setting('vw_magazine_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	));

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new VW_Magazine_Content_Creation( $wp_customize, 'vw_magazine_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','vw-magazine' ),
		),
		'section' => 'vw_magazine_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'vw-magazine' ),
	)));

	//Footer Text
	$wp_customize->add_section('vw_magazine_footer',array(
		'title'	=> __('Footer','vw-magazine'),
		'description'=> __('This section will appear in the footer','vw-magazine'),
		'panel' => 'vw_magazine_panel_id',
	));	

	//Selective Refresh
    $wp_customize->selective_refresh->add_partial('vw_magazine_footer_text', array( 
        'selector' => '.copyright p', 
        'render_callback' => 'vw_magazine_customize_partial_vw_magazine_footer_text', 
    ));
	
	$wp_customize->add_setting('vw_magazine_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_magazine_footer_text',array(
		'label'	=> __('Copyright Text','vw-magazine'),
		'section'=> 'vw_magazine_footer',
		'setting'=> 'vw_magazine_footer_text',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('vw_magazine_copyright_alingment',array(
        'default' => __('center','vw-magazine'),
        'sanitize_callback' => 'vw_magazine_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Magazine_Image_Radio_Control($wp_customize, 'vw_magazine_copyright_alingment', array(
        'type' => 'select',
        'label' => __('Copyright Alignment','vw-magazine'),
        'section' => 'vw_magazine_footer',
        'settings' => 'vw_magazine_copyright_alingment',
        'choices' => array(
            'left' => get_template_directory_uri().'/images/copyright1.png',
            'center' => get_template_directory_uri().'/images/copyright2.png',
            'right' => get_template_directory_uri().'/images/copyright3.png'
    ))));

    $wp_customize->add_setting('vw_magazine_copyright_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_copyright_padding_top_bottom',array(
		'label'	=> __('Copyright Padding Top Bottom','vw-magazine'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_magazine_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-magazine' ),
      	'section' => 'vw_magazine_footer'
    )));

    //Selective Refresh
    $wp_customize->selective_refresh->add_partial('vw_magazine_scroll_top_icon', array( 
        'selector' => '.scrollup i', 
        'render_callback' => 'vw_magazine_customize_partial_vw_magazine_scroll_top_icon', 
    ));

    $wp_customize->add_setting('vw_magazine_scroll_top_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Magazine_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_magazine_scroll_top_icon',array(
		'label'	=> __('Add Scroll to Top Icon','vw-magazine'),
		'transport' => 'refresh',
		'section'	=> 'vw_magazine_footer',
		'setting'	=> 'vw_magazine_scroll_top_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_magazine_scroll_to_top_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_scroll_to_top_font_size',array(
		'label'	=> __('Icon Font Size','vw-magazine'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_scroll_to_top_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_scroll_to_top_padding',array(
		'label'	=> __('Icon Top Bottom Padding','vw-magazine'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_scroll_to_top_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_scroll_to_top_width',array(
		'label'	=> __('Icon Width','vw-magazine'),
		'description'	=> __('Enter a value in pixels Example:20px','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_scroll_to_top_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_scroll_to_top_height',array(
		'label'	=> __('Icon Height','vw-magazine'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_magazine_scroll_to_top_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_magazine_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_magazine_scroll_to_top_border_radius', array(
		'label'       => esc_html__( 'Icon Border Radius','vw-magazine' ),
		'section'     => 'vw_magazine_footer',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_magazine_scroll_top_alignment',array(
        'default' => __('Right','vw-magazine'),
        'sanitize_callback' => 'vw_magazine_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Magazine_Image_Radio_Control($wp_customize, 'vw_magazine_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-magazine'),
        'section' => 'vw_magazine_footer',
        'settings' => 'vw_magazine_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/images/layout1.png',
            'Center' => get_template_directory_uri().'/images/layout2.png',
            'Right' => get_template_directory_uri().'/images/layout3.png'
    ))));

    //Woocommerce settings
	$wp_customize->add_section('vw_magazine_woocommerce_section', array(
		'title'    => __('WooCommerce Layout', 'vw-magazine'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

	//Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'vw_magazine_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','vw-magazine' ),
		'section' => 'vw_magazine_woocommerce_section'
    )));

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'vw_magazine_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_magazine_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Magazine_Toggle_Switch_Custom_Control( $wp_customize, 'vw_magazine_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','vw-magazine' ),
		'section' => 'vw_magazine_woocommerce_section'
    )));

    //Products per page
    $wp_customize->add_setting('vw_magazine_products_per_page',array(
		'default'=> '9',
		'sanitize_callback'	=> 'vw_magazine_sanitize_float'
	));
	$wp_customize->add_control('vw_magazine_products_per_page',array(
		'label'	=> __('Products Per Page','vw-magazine'),
		'description' => __('Display on shop page','vw-magazine'),
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 50,
        ),
		'section'=> 'vw_magazine_woocommerce_section',
		'type'=> 'number',
	));

    //Products per row
    $wp_customize->add_setting('vw_magazine_products_per_row',array(
		'default'=> '3',
		'sanitize_callback'	=> 'vw_magazine_sanitize_choices'
	));
	$wp_customize->add_control('vw_magazine_products_per_row',array(
		'label'	=> __('Products Per Row','vw-magazine'),
		'description' => __('Display on shop page','vw-magazine'),
		'choices' => array(
            '2' => '2',
			'3' => '3',
			'4' => '4',
        ),
		'section'=> 'vw_magazine_woocommerce_section',
		'type'=> 'select',
	));

	//Products padding
	$wp_customize->add_setting('vw_magazine_products_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_products_padding_top_bottom',array(
		'label'	=> __('Products Padding Top Bottom','vw-magazine'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_products_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_products_padding_left_right',array(
		'label'	=> __('Products Padding Left Right','vw-magazine'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-magazine'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-magazine' ),
        ),
		'section'=> 'vw_magazine_woocommerce_section',
		'type'=> 'text'
	));

	//Products box shadow
	$wp_customize->add_setting( 'vw_magazine_products_box_shadow', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_magazine_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_magazine_products_box_shadow', array(
		'label'       => esc_html__( 'Products Box Shadow','vw-magazine' ),
		'section'     => 'vw_magazine_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Products border radius
    $wp_customize->add_setting( 'vw_magazine_products_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_magazine_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_magazine_products_border_radius', array(
		'label'       => esc_html__( 'Products Border Radius','vw-magazine' ),
		'section'     => 'vw_magazine_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

    // Has to be at the top
	$wp_customize->register_panel_type( 'VW_Magazine_WP_Customize_Panel' );
	$wp_customize->register_section_type( 'VW_Magazine_WP_Customize_Section' );
}

add_action( 'customize_register', 'vw_magazine_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

if ( class_exists( 'WP_Customize_Panel' ) ) {
  	class VW_Magazine_WP_Customize_Panel extends WP_Customize_Panel {
	    public $panel;
	    public $type = 'vw_magazine_panel';
	    public function json() {

	      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'type', 'panel', ) );
	      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
	      $array['content'] = $this->get_content();
	      $array['active'] = $this->active();
	      $array['instanceNumber'] = $this->instance_number;
	      return $array;
    	}
  	}
}

if ( class_exists( 'WP_Customize_Section' ) ) {
  	class VW_Magazine_WP_Customize_Section extends WP_Customize_Section {
	    public $section;
	    public $type = 'vw_magazine_section';
	    public function json() {

	      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'panel', 'type', 'description_hidden', 'section', ) );
	      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
	      $array['content'] = $this->get_content();
	      $array['active'] = $this->active();
	      $array['instanceNumber'] = $this->instance_number;

	      if ( $this->panel ) {
	        $array['customizeAction'] = sprintf( 'Customizing &#9656; %s', esc_html( $this->manager->get_panel( $this->panel )->title ) );
	      } else {
	        $array['customizeAction'] = 'Customizing';
	      }
	      return $array;
    	}
  	}	
}

// Enqueue our scripts and styles
function vw_magazine_customize_controls_scripts() {
  wp_enqueue_script( 'customizer-controls', get_theme_file_uri( '/js/customizer-controls.js' ), array(), '1.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'vw_magazine_customize_controls_scripts' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Magazine_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Magazine_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Magazine_Customize_Section_Pro($manager,'example_1',array(
			'priority'   => 1,
			'title'    => esc_html__( 'VW Magazine Pro', 'vw-magazine' ),
			'pro_text' => esc_html__( 'Upgrade Pro', 'vw-magazine' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/premium-magazine-wordpress-theme/')
		)));

		$manager->add_section(new VW_Magazine_Customize_Section_Pro($manager,'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'Documentation', 'vw-magazine' ),
			'pro_text' => esc_html__( 'Docs', 'vw-magazine' ),
			'pro_url'  => admin_url( 'themes.php?page=vw_magazine_guide' )
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-magazine-customize-controls', trailingslashit( get_template_directory_uri() ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-magazine-customize-controls', trailingslashit( get_template_directory_uri() ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Magazine_Customize::get_instance();